16#ifndef __CLANG_HIP_RUNTIME_WRAPPER_H__
17#define __CLANG_HIP_RUNTIME_WRAPPER_H__
21#define __host__ __attribute__((host))
22#define __device__ __attribute__((device))
23#define __global__ __attribute__((global))
24#define __shared__ __attribute__((shared))
25#define __constant__ __attribute__((constant))
26#define __managed__ __attribute__((managed))
28#define __cluster_dims__(...) __attribute__((cluster_dims(__VA_ARGS__)))
29#define __no_cluster__ __attribute__((no_cluster))
31#if !defined(__cplusplus) || __cplusplus < 201103L
35#if !defined(__HIPCC_RTC__)
36#if __has_include("hip/hip_version.h")
37#include "hip/hip_version.h"
41typedef __SIZE_TYPE__ __hip_size_t;
47#if HIP_VERSION_MAJOR * 100 + HIP_VERSION_MINOR >= 405
48__device__ unsigned long long __ockl_dm_alloc(
unsigned long long __size);
49__device__ void __ockl_dm_dealloc(
unsigned long long __addr);
50#if __has_feature(address_sanitizer)
51__device__ unsigned long long __asan_malloc_impl(
unsigned long long __size,
52 unsigned long long __pc);
53__device__ void __asan_free_impl(
unsigned long long __addr,
54 unsigned long long __pc);
56 unsigned long long __pc = (
unsigned long long)__builtin_return_address(0);
57 return (
void *)__asan_malloc_impl(__size, __pc);
60 unsigned long long __pc = (
unsigned long long)__builtin_return_address(0);
61 __asan_free_impl((
unsigned long long)__ptr, __pc);
65 return (
void *) __ockl_dm_alloc(__size);
68 __ockl_dm_dealloc((
unsigned long long)__ptr);
72#if __HIP_ENABLE_DEVICE_MALLOC__
73__device__ void *__hip_malloc(__hip_size_t __size);
76 return __hip_malloc(__size);
96#if !defined(__HIPCC_RTC__)
106#if __has_include("hip/hip_version.h")
107#include "hip/hip_version.h"
110typedef __SIZE_TYPE__
size_t;
115#pragma push_macro("NULL")
116#pragma push_macro("uint32_t")
117#pragma push_macro("uint64_t")
118#pragma push_macro("CHAR_BIT")
119#pragma push_macro("INT_MAX")
120#pragma push_macro("INT_MIN")
121#define NULL (void *)0
122#define uint32_t __UINT32_TYPE__
123#define uint64_t __UINT64_TYPE__
124#define CHAR_BIT __CHAR_BIT__
125#define INT_MAX __INTMAX_MAX__
126#define INT_MIN (-__INT_MAX__ - 1)
133#if defined(__HIPCC_RTC__)
143#define __CLANG_HIP_RUNTIME_WRAPPER_INCLUDED__ 1
144#if defined(__HIPCC_RTC__)
145#pragma pop_macro("NULL")
146#pragma pop_macro("uint32_t")
147#pragma pop_macro("uint64_t")
148#pragma pop_macro("CHAR_BIT")
149#pragma pop_macro("INT_MAX")
150#pragma pop_macro("INT_MIN")
_Float16 __2f16 __attribute__((ext_vector_type(2)))
Zeroes the upper 128 bits (bits 255:128) of all YMM registers.
__SIZE_TYPE__ size_t
The unsigned integer type of the result of the sizeof operator.